from db.MongoRepository import MongoRepository
from messaging.ReconnectingMessageManager import ReconnectingMessageManager
import json

import logging
LOGGER = logging.getLogger(__name__)

class MessageHandler:
    _mongo_repo = None
    _message_sender = None

    def __init__(self):
        self._mongo_repo = MongoRepository()
        self._init_message_sender()
    
    def _init_message_sender(self):
        self._message_sender = ReconnectingMessageManager.getInstance()
        self._message_sender.create_message_destination('datahub', 'direct')

    def handle_generic(self, body):
        LOGGER.info(f"Received message: {body}")

        message = None
        try:
            message = json.loads(body)
        except ValueError:
            LOGGER.warning("Message is not in JSON format and is ignored")
            return

        if not 'type' in message:
            LOGGER.warning("Message has no type field and is ignored")
            return
        
        if message['type'] == 'blockchain-transaction':
            self.handle_blockchain_transaction(message['content'])
        else:
            LOGGER.info("Message Type could not be processed")
            
    def handle_blockchain_transaction(self, transaction):
        self._mongo_repo.insert_trace(transaction)
        
        # inform semantic linking microservice
        msg = {'type': 'new-traces-available'}
        self._message_sender.send_message('datahub', 'semantic-linking', json.dumps(msg))